function [W,a,n,t] = solvegame(w,N,r,A1,A2,c1,c2,b1,b2,dir)
% [W,a,n,t] = solvegame(w,N,r,A1,A2,c1,c2,b1,b2,dir)
% solves equation using fourth-order Runge-Kutta
% w is the starting point, and N is the starting direction
% A1, A2 are action sets and c1,c2,b1,b2 define payoffs 
% c1(a1) + b1(a1) a2 for player 1 and c2(a2) + b2(a2) a1 for player 2
% dir = +/- 1 is the direction in which the curve is solved
% procedure stops when the curve gets far enough from the set of feasible
% payoffs

prec = 1000;
W = zeros(prec*6.283,4);  % 6.283 = 2*pi
a = zeros(prec*6.283,2);
[g1,g2,gamma1,gamma2,m1,m2] = payinc(A1,A2,c1,c2,b1,b2);

% W1, W2, cos(alpha), sin(alpha)
W(1,1) = w(1); 
W(1,2) = w(2);
W(1,3) = N(1);
W(1,4) = N(2);

% minmax
v1L = min(max(g1));
v1H = max(max(g1));
v2L = max(min(g2));
v2H = max(max(g2));

eps = dir/prec;
% incremental step by which the angle changes

for n = 1:(prec*6.283-1),
  % step 1 
  [k, a(n+1,:),t] = kappa(W(n,1:2),W(n,3:4),r,g1,g2,gamma1,gamma2,m1,m2); 
  % if (t == 1) return; end  % a static Nash equilibrium is separated from the curve, curve feasible
  W1P1 = - W(n,4)/k;
  W2P1 = W(n,3)/k;
  W3P1 = - W(n,4);
  W4P1 = W(n,3);

  % step 2
  W1_temp = W(n,1) + 0.5*W1P1*eps;
  W2_temp = W(n,2) + 0.5*W2P1*eps;
  W3_temp = W(n,3) + 0.5*W3P1*eps;
  W4_temp = W(n,4) + 0.5*W4P1*eps;
  [k,b,t]= kappa([W1_temp W2_temp],[W3_temp W4_temp],r,g1,g2,gamma1,gamma2,m1,m2);
  % if (t == 1) return; end
  W1P2 = - W4_temp/k;
  W2P2 = W3_temp/k;
  W3P2 = - W4_temp;
  W4P2 = W3_temp;

  % step 3
  W1_temp = W(n,1) + 0.5*W1P2*eps;
  W2_temp = W(n,2) + 0.5*W2P2*eps;
  W3_temp = W(n,3) + 0.5*W3P2*eps;
  W4_temp = W(n,4) + 0.5*W4P2*eps;
  [k,b,t] = kappa([W1_temp W2_temp],[W3_temp W4_temp],r,g1,g2,gamma1,gamma2,m1,m2);
  % if (t == 1) return; end
  W1P3 = - W4_temp/k;
  W2P3 = W3_temp/k;
  W3P3 = - W4_temp;
  W4P3 = W3_temp;

  % step 4
  W1_temp = W(n,1) + W1P3*eps;
  W2_temp = W(n,2) + W2P3*eps;
  W3_temp = W(n,3) + W3P3*eps;
  W4_temp = W(n,4) + W4P3*eps;
  [k,b,t] = kappa([W1_temp W2_temp],[W3_temp W4_temp],r,g1,g2,gamma1,gamma2,m1,m2);
  % if (t == 1) return; end
  W1P4 = - W4_temp/k;
  W2P4 = W3_temp/k;
  W3P4 = - W4_temp;
  W4P4 = W3_temp;

  % New value
  W(n+1,1) = W(n,1) + eps*(W1P1/6 + W1P2/3 + W1P3/3 + W1P4/6);
  W(n+1,2) = W(n,2) + eps*(W2P1/6 + W2P2/3 + W2P3/3 + W2P4/6);
  W(n+1,3) = W(n,3) + eps*(W3P1/6 + W3P2/3 + W3P3/3 + W3P4/6);
  W(n+1,4) = W(n,4) + eps*(W4P1/6 + W4P2/3 + W4P3/3 + W4P4/6);
  
  t = check(W(n,1:2),v1L,v2L,v1H,v2H);
  if (t == -1) return; end

end
